@@ -69,7 +69,7 @@ CHARSET make_reverse_map(short int *charset) {
 /* Reads charset file (as got from ftp.unicode.org) and returns array of*/
 /* 256 short ints (malloced) mapping from charset t unicode             */
 /************************************************************************/
-short int * read_charset(char *filename) {
+short int * read_charset(const char *filename) {
 	char *path;
 	FILE *f;
 	short int *new=calloc(sizeof(short int),256);
